@@ -1,7 +1,10 @@
-# This file is Copyright (c) 2016-2019 Florent Kermarrec <florent@enjoy-digital.fr>
-# This file is Copyright (c) 2018 bunnie <bunnie@kosagi.com>
-# This file is Copyright (c) 2016 Tim 'mithro' Ansell <mithro@mithis.com>
-# License: BSD
+#
+# This file is part of LiteScope.
+#
+# Copyright (c) 2016-2019 Florent Kermarrec <florent@enjoy-digital.fr>
+# Copyright (c) 2018 bunnie <bunnie@kosagi.com>
+# Copyright (c) 2016 Tim 'mithro' Ansell <mithro@mithis.com>
+# SPDX-License-Identifier: BSD-2-Clause
 
 from migen import *
 from migen.genlib.misc import WaitTimer
@@ -77,7 +80,7 @@ class _Trigger(Module, AutoCSR):
         self.submodules += flush
         self.comb += [
             flush.wait.eq(~(~enable & enable_d)), # flush when disabling
-            hit.eq((sink.data & mem.source.mask) == mem.source.value),
+            hit.eq((sink.data & mem.source.mask) == (mem.source.value & mem.source.mask)),
             mem.source.ready.eq((enable & hit) | ~flush.done),
         ]
 
@@ -89,7 +92,6 @@ class _Trigger(Module, AutoCSR):
             source.hit.eq(done)
         ]
 
-
 class _SubSampler(Module, AutoCSR):
     def __init__(self, data_width):
         self.sink   = sink   = stream.Endpoint(core_layout(data_width))
@@ -159,12 +161,10 @@ class _Storage(Module, AutoCSR):
         self.specials += MultiReg(self.enable.storage, enable, "scope")
         self.sync.scope += enable_d.eq(enable)
 
-        length = Signal(max=depth)
-        offset = Signal(max=depth)
-        self.specials += [
-            MultiReg(self.length.storage, length, "scope"),
-            MultiReg(self.offset.storage, offset, "scope")
-        ]
+        length = Signal().like(self.length.storage)
+        offset = Signal().like(self.offset.storage)
+        self.specials += MultiReg(self.length.storage, length, "scope")
+        self.specials += MultiReg(self.offset.storage, offset, "scope")
 
         # Status re-synchronization
         done = Signal()
@@ -226,7 +226,7 @@ class _Storage(Module, AutoCSR):
 
 
 class LiteScopeAnalyzer(Module, AutoCSR):
-    def __init__(self, groups, depth, clock_domain="sys", trigger_depth=16, csr_csv=None):
+    def __init__(self, groups, depth, clock_domain="sys", trigger_depth=16, csr_csv="analyzer.csv"):
         self.groups = groups = self.format_groups(groups)
         self.depth  = depth
 
